pub struct AnalyzeImageOutput {
pub image: ImageSummary,
pub extraction: ExtractionSummary,
pub measurement: MeasurementSummary,
pub rankings: Vec<CandidateRankingSummary>,
pub evidence_cards: Vec<EvidenceCardSummary>,
pub warnings: Vec<String>,
pub limitations: Vec<String>,
}Fields
image: ImageSummaryextraction: ExtractionSummarymeasurement: MeasurementSummaryrankings: Vec<CandidateRankingSummary>evidence_cards: Vec<EvidenceCardSummary>warnings: Vec<String>limitations: Vec<String>Trait Implementations
Sourceimpl Clone for AnalyzeImageOutput
impl Clone for AnalyzeImageOutput
Sourcefn clone(&self) -> AnalyzeImageOutput
fn clone(&self) -> AnalyzeImageOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalyzeImageOutput
impl Debug for AnalyzeImageOutput
Sourceimpl<'de> Deserialize<'de> for AnalyzeImageOutput
impl<'de> Deserialize<'de> for AnalyzeImageOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnalyzeImageOutput
impl JsonSchema for AnalyzeImageOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AnalyzeImageOutput
impl PartialEq for AnalyzeImageOutput
Sourcefn eq(&self, other: &AnalyzeImageOutput) -> bool
fn eq(&self, other: &AnalyzeImageOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AnalyzeImageOutput
impl Serialize for AnalyzeImageOutput
impl StructuralPartialEq for AnalyzeImageOutput