pub struct ManualRankOutput {
pub status: String,
pub subject: SubjectSummary,
pub rankings: Vec<CandidateRankingSummary>,
pub uncertainty: String,
}Fields
status: Stringsubject: SubjectSummaryrankings: Vec<CandidateRankingSummary>uncertainty: StringTrait Implementations
Sourceimpl Clone for ManualRankOutput
impl Clone for ManualRankOutput
Sourcefn clone(&self) -> ManualRankOutput
fn clone(&self) -> ManualRankOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManualRankOutput
impl Debug for ManualRankOutput
Sourceimpl<'de> Deserialize<'de> for ManualRankOutput
impl<'de> Deserialize<'de> for ManualRankOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManualRankOutput
impl JsonSchema for ManualRankOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ManualRankOutput
impl PartialEq for ManualRankOutput
Sourcefn eq(&self, other: &ManualRankOutput) -> bool
fn eq(&self, other: &ManualRankOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ManualRankOutput
impl Serialize for ManualRankOutput
impl StructuralPartialEq for ManualRankOutput