pub struct ReadinessOutput {
pub sdk_available: bool,
pub vision_helper_available: bool,
pub python_version: Option<String>,
pub missing_packages: Vec<String>,
pub missing_models: Vec<String>,
pub warnings: Vec<String>,
}Fields
sdk_available: boolvision_helper_available: boolpython_version: Option<String>missing_packages: Vec<String>missing_models: Vec<String>warnings: Vec<String>Trait Implementations
Sourceimpl Clone for ReadinessOutput
impl Clone for ReadinessOutput
Sourcefn clone(&self) -> ReadinessOutput
fn clone(&self) -> ReadinessOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadinessOutput
impl Debug for ReadinessOutput
Sourceimpl<'de> Deserialize<'de> for ReadinessOutput
impl<'de> Deserialize<'de> for ReadinessOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReadinessOutput
impl JsonSchema for ReadinessOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReadinessOutput
impl PartialEq for ReadinessOutput
Sourcefn eq(&self, other: &ReadinessOutput) -> bool
fn eq(&self, other: &ReadinessOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ReadinessOutput
impl Serialize for ReadinessOutput
impl StructuralPartialEq for ReadinessOutput